# plugin_info, a plugin for working with information about plugins.
# Copyright (C) 2006 Canonical Limited.
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# 

"""plugin-info commands."""

import errno

from bzrlib.branch import Branch
import bzrlib.commands
from bzrlib import errors
from bzrlib.option import Option
from bzrlib.plugins.plugin_info.extract import *
from bzrlib.trace import note


class cmd_plugin_info(bzrlib.commands.Command):
    """Report the metadata for a plugin.

    This reads the metadata for a plugin from a branch or directory containing
    the plugin and reports it to stdout.

    Plugins with no setup.py will be skipped. Plugins with a setup.py that
    tries to install or otherwise run code may fail to probe - this command
    deliberately lets that interrupt the scan: fix the plugin or don't probe
    it.
    """

    takes_args = ['location+']
    takes_options = [
        Option('python', help='output a python script with the plugin metadata.'),
        ]


    def dump_info(self, plugin_info):
        if self.python:
            self.outf.write(plugin_info.to_python())
            self.outf.write("""if plugin.name:
    plugins.append(plugin)
""")
        else:
            self.outf.write(str(plugin_info))

    def run(self, location_list=[], python=False):
        self.python = python
        if self.python:
            self.outf.write("""from extract import PluginInfo
plugins = []
""")
        for url in location_list:
            note("Probing %s" % url)
            try:
                self.dump_info(extract_info_local(url))
            except IOError:
                try:
                    branch = Branch.open(url)
                except errors.NotBranchError:
                    raise
                else:
                    try:
                        self.dump_info(extract_info_branch(branch))
                    except IOError, e:
                        if e.errno != errno.ENOENT:
                            raise
                        note("No info for %s" % url)
            self.outf.write('\n')
