# plugin_info, a plugin for working with information about plugins.
# Copyright (C) 2008, 2010 Canonical Limited.
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# 

"""Tests for the commands supplied by plugin-info."""

from bzrlib.tests import TestCaseWithTransport
from testtools.matchers import DocTestMatches


class TestPluginInfo(TestCaseWithTransport):

    def sample_setup(self):
        return """
bzr_plugin_name = "foo_bar"
bzr_commands = ["a-command"]
bzr_plugin_version = (1, 2, 3, 'dev', 0)
bzr_minimum_version = (1, 2, 0)
bzr_maximum_version = (1, 3, 0)
bzr_control_formats = {"bzr-meta":{".bzr/branch-format":"Bazaar-NG meta directory, format 1\\n"}}
bzr_checkout_formats = {"Bazaar Working Tree Format 4 (bzr 0.15)\\n":"dirstate"}
bzr_branch_formats = {"Bazaar Branch Format 6 (bzr 0.15)\\n":"branch 6"}
bzr_repository_formats = {"Bazaar pack repository format 1 (needs bzr 0.92)\\n":"packs"}
bzr_transports = ["hg+ssh://"]
"""

    def setup_plugins(self):
        tree = self.make_branch_and_tree('plugin')
        self.build_tree_contents([('plugin/setup.py', self.sample_setup())])
        tree.add(['setup.py'])
        tree.commit('yay history')
        self.build_tree(['plugin2/'])
        self.build_tree_contents([('plugin2/setup.py', self.sample_setup())])

    def test_extract_info_branch(self):
        self.setup_plugins()
        out, err = self.run_bzr(['plugin-info', 'plugin', 'plugin2'])
        self.assertEqual(
"""foo_bar(1.2.3dev0) from plugin supplies commands("a-command"), control formats("bzr-meta"), checkout formats("dirstate"), branch formats("branch 6"), repository formats("packs"), transports("hg+ssh://").
foo_bar(1.2.3dev0) from plugin2 supplies commands("a-command"), control formats("bzr-meta"), checkout formats("dirstate"), branch formats("branch 6"), repository formats("packs"), transports("hg+ssh://").
""", out)
        self.assertEqual('Probing plugin\nProbing plugin2\n', err)

    def test_extract_info_python(self):
        self.setup_plugins()
        out, err = self.run_bzr(['plugin-info', 'plugin', 'plugin2', '--python'])
        expected = """from extract import PluginInfo
plugins = []
plugin = PluginInfo()
plugin.name = 'foo_bar'
plugin.location = 'plugin'
plugin.version_info = (1, 2, 3, 'dev', 0)
plugin.minimum_bzr_version = (1, 2, 0)
plugin.maximum_bzr_version = (1, 3, 0)
plugin.commands = ['a-command']
plugin.control_formats = {'bzr-meta': {'.bzr/branch-format': 'Bazaar-NG meta directory, format 1\\n'}}
plugin.checkout_formats = {'Bazaar Working Tree Format 4 (bzr 0.15)\\n': 'dirstate'}
plugin.branch_formats = {'Bazaar Branch Format 6 (bzr 0.15)\\n': 'branch 6'}
plugin.repository_formats = {'Bazaar pack repository format 1 (needs bzr 0.92)\\n': 'packs'}
plugin.transports = ['hg+ssh://']
if plugin.name:
    plugins.append(plugin)
<BLANKLINE>
plugin = PluginInfo()
plugin.name = 'foo_bar'
plugin.location = 'plugin2'
plugin.version_info = (1, 2, 3, 'dev', 0)
plugin.minimum_bzr_version = (1, 2, 0)
plugin.maximum_bzr_version = (1, 3, 0)
plugin.commands = ['a-command']
plugin.control_formats = {'bzr-meta': {'.bzr/branch-format': 'Bazaar-NG meta directory, format 1\\n'}}
plugin.checkout_formats = {'Bazaar Working Tree Format 4 (bzr 0.15)\\n': 'dirstate'}
plugin.branch_formats = {'Bazaar Branch Format 6 (bzr 0.15)\\n': 'branch 6'}
plugin.repository_formats = {'Bazaar pack repository format 1 (needs bzr 0.92)\\n': 'packs'}
plugin.transports = ['hg+ssh://']
if plugin.name:
    plugins.append(plugin)
<BLANKLINE>
"""
        self.assertThat(out, DocTestMatches(expected))
        self.assertEqual('Probing plugin\nProbing plugin2\n', err)

